==> tagcoll_1.5.1.orig.tar.gz: tagcoll-1.5.1/tagcoll/Serializer.cc <==
/*
 * Serializer for ITEMs and TAGs
 *
 * Copyright (C) 2005  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <tagcoll/Serializer.h>

using namespace std;
using namespace Tagcoll;

#if 0
template<typename IN, typename OUT>
OUT Converter<IN, OUT>::operator()(const IN& item)
{
	return OUT(item);
}

template<typename IN, typename OUT>
OpSet<OUT> Converter<IN, OUT>::operator()(const OpSet<IN>& items)
{
	OpSet<OUT> res;

	for (typename OpSet<IN>::const_iterator i = items.begin();
			i != items.end(); i++)
	{
		OUT t = (*this)(*i);
		if (t != OUT())
			res += t;
	}

	return res;
}
#endif

#ifndef INSTANTIATING_TEMPLATES
#include <string>

namespace Tagcoll {
	template class Converter<std::string, std::string>;
	template class ConversionFilter<std::string, std::string, std::string, std::string>;
}
#endif

#ifdef COMPILE_TESTSUITE

#include <tests/test-utils.h>

namespace tut {
using namespace tut_tagcoll;

struct tagcoll_serializer_shar {
};
TESTGRP(tagcoll_serializer);

template<> template<>
void to::test<1>()
{
	ensure(false);
}

}

#endif

// vim:set ts=4 sw=4:

==> tagcoll_1.6.3-1.tar.gz: tagcoll-1.6.3/tagcoll/Serializer.cc <==
/*
 * Serializer for ITEMs and TAGs
 *
 * Copyright (C) 2005  Enrico Zini <enrico@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <tagcoll/Serializer.h>

using namespace std;
using namespace Tagcoll;

#if 0
template<typename IN, typename OUT>
OUT Converter<IN, OUT>::operator()(const IN& item)
{
	return OUT(item);
}

template<typename IN, typename OUT>
OpSet<OUT> Converter<IN, OUT>::operator()(const OpSet<IN>& items)
{
	OpSet<OUT> res;

	for (typename OpSet<IN>::const_iterator i = items.begin();
			i != items.end(); i++)
	{
		OUT t = (*this)(*i);
		if (t != OUT())
			res += t;
	}

	return res;
}
#endif

#ifndef INSTANTIATING_TEMPLATES
#include <string>

namespace Tagcoll {
	template class Converter<std::string, std::string>;
	template class ConversionFilter<std::string, std::string, std::string, std::string>;
}
#endif

#ifdef COMPILE_TESTSUITE

#include <tests/test-utils.h>

namespace tut {
using namespace tut_tagcoll;

struct tagcoll_serializer_shar {
};
TESTGRP(tagcoll_serializer);

template<> template<>
void to::test<1>()
{
	TrivialConverter<string, string> sconv;
	TrivialConverter<int, int> iconv;

	gen_ensure_equals(sconv("cippo lippo"), "cippo lippo");
	gen_ensure_equals(sconv("ciao"), "ciao");
	gen_ensure_equals(sconv(""), "");
	gen_ensure_equals(iconv(0), 0);
	gen_ensure_equals(iconv(30), 30);
	gen_ensure_equals(iconv(-30), -30);
}

}

#endif

// vim:set ts=4 sw=4:
